# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### Bug Fixes

- 🐞 import fix for validx.[any imports access] (#12)
- Fix coverage errors
- Logo url fixed
- 🐞 actions/upload-artifact@v4 conflict fix
- 🐞 actions/upload-artifact@v4 download path fix

### Documentation

- Add readme file
- Pre-commit and ci badges added.
- 📝 ip_address example usage added into readme.md
- 📝 code-coverage badges are added
- 📝 codefactor badge added
- Add hash validator to readme with examples
- Logo resized
- 📝 changelog updated

### Features

- ✨ initial commit validX
- ✨ initial country_code and project renamed to validx (lowercase)
- ✨ country code validations added
- ✨ country code rename for shorter function name
- 🐍 more python gitignore added
- 🚀 devcontainer-rust added
- Add email validator
- Delete python/validX directory
- 🏗️ introduce poetry for dev only setup added (#13)
- 🧪 initial python tests are added
- 🧪 more email tests are added
- Add ip_address validator
- 🧪 ip-address tests are added
- 🚀 initial hash - md5 validator added
- 🚀 sha1,sha224,sha256, validator added
- 🚀 sha1,sha224,sha256 validators and tests are added
- Add mac_address validator
- Add domain validator
- Add url validation (#28)
- Add logo for project (#31)
- Change project name in readme file (#32)
- 🚀 project renamed to yuko
- 🚀 git cliff config and CHANGELOG generated
- 🚀 dependabot.yml added (#34)
- 🚀 yuko __version__ added

### Miscellaneous Tasks

- 👷 initial pre-commit
- 👷 code-coverage ci and codecov ci added (#18)
- 👷 pre-commit configuration updated
- ⬆ pre_commit autoupdate
- 👷 rustsec audit check added
- ⬆ pre_commit autoupdate
- ⬆ pre_commit autoupdate
- Add develop name into CI files
- Gitattribute file added
- 👷 dependabot prefix updated
- 👷 dependabot rust package check added
- 👷 mergify github action config added
- Funding.yml added
- Github action settings, bot configs updated. #39

### Refactor

- Improve domain validator and fix tests

### Styling

- 💄 .editorconfig added

### Testing

- Add more test case for ip validator
- 🧪 sha1 validator and sha1 test case fix
- Add missing test case for domain whitespace regex

<!-- generated by git-cliff -->
